.. _xray_data_README:

Auxiliary Data Files for use with yt's Photon Simulator
=======================================================

Included in the `xray_data <https://yt-project.org/data/xray_data.tar.gz>`_ package are a number of files that you may find
useful when working with yt's X-ray `photon_simulator
<photon_simulator.html>`_  analysis module. They have been tested to give spectral fitting results
consistent with input parameters.

Spectral Model Tables
---------------------

* tbabs_table.h5:

  Tabulated values of the galactic absorption cross-section in HDF5
  format, generated from the routines at http://pulsar.sternwarte.uni-erlangen.de/wilms/research/tbabs/

ARFs and RMFs
-------------

We have tested the following ARFs and RMFs with the photon
simulator. These can be used to generate a very simplified
representation of an X-ray observation, using a uniform, on-axis
response. For more accurate models of X-ray observations we suggest
using MARX or SIMX (detailed below_).

* Chandra: chandra_ACIS-S3_onaxis_arf.fits, chandra_ACIS-S3_onaxis_rmf.fits

  Generated from the CIAO tools, on-axis on the ACIS-S3 chip.

* XMM-Newton: pn-med.arf, pn-med.rmf

  EPIC pn CCDs (medium filter), taken from SIMX

* Astro-H: sxt-s_100208_ts02um_intall.arf, ah_sxs_7ev_basefilt_20090216.rmf

  SXT-S+SXS responses taken from http://astro-h.isas.jaxa.jp/researchers/sim/response.html

* NuSTAR: nustarA.arf, nustarA.rmf

  Averaged responses for NuSTAR telescope A generated by Dan Wik (NASA/GSFC)

.. _below:


Other Useful Things Not Included Here
-------------------------------------

* AtomDB: http://www.atomdb.org

  FITS table data for emission lines and continuum emission. Must have
  it installed to use the TableApecModel spectral model.

* PyXspec: https://heasarc.gsfc.nasa.gov/xanadu/xspec/python/html/

  Python interface to the XSPEC spectral-fitting program. Two of the
  spectral models for the photon simulator use it.

* MARX: https://space.mit.edu/ASC/MARX/

  Detailed ray-trace simulations of Chandra.

* SIMX: http://hea-www.harvard.edu/simx/

  Simulates a photon-counting detector's response to an input source,
  including a simplified models of telescopes.
